"""
Entry point to run data processing and analysis commands.
"""

import click

import data.parse_mat as parse_mat
import data.parse_shp as profile_features
import data.csv_to_shp as csv_to_shp
import analysis.forecast_twl as forecast_twl
import analysis.forecasted_storm_impacts as forecasted_storm_impacts
import analysis.observed_storm_impacts as observed_storm_impacts
import data.apply_manual_overwrites as apply_manual_overwrites

# Disable numpy warnings
import warnings

warnings.simplefilter(action="ignore", category=FutureWarning)


@click.group()
def cli():
    pass


if __name__ == "__main__":
    cli.add_command(parse_mat.create_waves_csv)
    cli.add_command(parse_mat.create_sites_and_profiles_csv)
    cli.add_command(parse_mat.create_tides_csv)
    cli.add_command(parse_mat.create_profile_features)
    # cli.add_command(profile_features.create_profile_features)
    cli.add_command(csv_to_shp.sites_csv_to_shp)
    cli.add_command(forecast_twl.create_twl_forecast)
    cli.add_command(forecasted_storm_impacts.create_forecasted_impacts)
    cli.add_command(observed_storm_impacts.create_observed_impacts)
    cli.add_command(apply_manual_overwrites.apply_profile_features_overwrite)
    cli()
